package com.ruoyi.nanjing.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.nanjing.mapper.TRpBarcoderelationshipMapper;
import com.ruoyi.nanjing.domain.TRpBarcoderelationship;
import com.ruoyi.nanjing.service.ITRpBarcoderelationshipService;
import com.ruoyi.common.core.text.Convert;

/**
 * BarcodeRelationShipService业务层处理
 * 
 * @author limy
 * @date 2021-01-29
 */
@Service
public class TRpBarcoderelationshipServiceImpl implements ITRpBarcoderelationshipService 
{
    @Autowired
    private TRpBarcoderelationshipMapper tRpBarcoderelationshipMapper;

    /**
     * 查询BarcodeRelationShip
     * 
     * @param ID BarcodeRelationShipID
     * @return BarcodeRelationShip
     */
    @Override
    public TRpBarcoderelationship selectTRpBarcoderelationshipById(Long ID)
    {
        return tRpBarcoderelationshipMapper.selectTRpBarcoderelationshipById(ID);
    }

    /**
     * 查询BarcodeRelationShip列表
     * 
     * @param tRpBarcoderelationship BarcodeRelationShip
     * @return BarcodeRelationShip
     */
    @Override
    public List<TRpBarcoderelationship> selectTRpBarcoderelationshipList(TRpBarcoderelationship tRpBarcoderelationship)
    {
        return tRpBarcoderelationshipMapper.selectTRpBarcoderelationshipList(tRpBarcoderelationship);
    }

    /**
     * 新增BarcodeRelationShip
     * 
     * @param tRpBarcoderelationship BarcodeRelationShip
     * @return 结果
     */
    @Override
    public int insertTRpBarcoderelationship(TRpBarcoderelationship tRpBarcoderelationship)
    {
        return tRpBarcoderelationshipMapper.insertTRpBarcoderelationship(tRpBarcoderelationship);
    }

    /**
     * 修改BarcodeRelationShip
     * 
     * @param tRpBarcoderelationship BarcodeRelationShip
     * @return 结果
     */
    @Override
    public int updateTRpBarcoderelationship(TRpBarcoderelationship tRpBarcoderelationship)
    {
        return tRpBarcoderelationshipMapper.updateTRpBarcoderelationship(tRpBarcoderelationship);
    }

    /**
     * 删除BarcodeRelationShip对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTRpBarcoderelationshipByIds(String ids)
    {
        return tRpBarcoderelationshipMapper.deleteTRpBarcoderelationshipByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除BarcodeRelationShip信息
     * 
     * @param ID BarcodeRelationShipID
     * @return 结果
     */
    @Override
    public int deleteTRpBarcoderelationshipById(Long ID)
    {
        return tRpBarcoderelationshipMapper.deleteTRpBarcoderelationshipById(ID);
    }
}
